@@ -53,6 +53,9 @@ struct ftp_dirs {
 PlugExport int plugin_init(struct arglist * desc);
 PlugExport int plugin_init(struct arglist * desc)
 {
+  plug_set_id(desc, 10332);
+  plug_set_cve_id(desc, "CAN-1999-0527");
+ 
   plug_set_name(desc, FR_NAME, "francais");
   plug_set_name(desc, EN_NAME, NULL);
   
@@ -121,7 +124,7 @@ PlugExport int plugin_run(struct arglist * env)
   report = emalloc(255+strlen(list));
   sprintf(report, "\
 The following directories are world-writeable. You should\n\
-correct this problem quickly\n%s\n", list);
+correct this problem quickly\n%s\nRisk factor : Medium\n", list);
   post_hole(env, port, report);
   efree(&report);
  }
