@@ -33,8 +33,8 @@ la section 'plugins options' pour le configurer"
 #define FR_FAMILY "Scanners de ports"
 
 
-#define TCP_PORTSCAN "TCP scanning technique : "
-#define TCP_DFL "connect();SYN scan;FIN scan;Xmas Tree scan;Null Scan"
+#define TCP_PORTSCAN "TCP scanning technique :"
+#define TCP_DFL "connect();SYN scan;FIN scan;Xmas Tree scan;Null scan"
 
 
 
@@ -59,7 +59,7 @@ la section 'plugins options' pour le configurer"
 #define FAST_SCAN "Perform a fast scan"
 #define FAST_DFL "no"
 
-#define SOURCE_PORT "Source port : "
+#define SOURCE_PORT "Source port :"
 #define SOURCE_DFL "any"
 
 static int valid_port_range(char *);
@@ -114,11 +114,14 @@ ptycall_nmap
 
   atexit (kill_nmap);
   do {
-    while ((s = fgets (buf, sizeof (buf), fp)) == 0 && errno == EAGAIN)
+    while (((s = fgets (buf, sizeof (buf), fp))) == 0 && (errno == EAGAIN))
       sleep (1);
     if (s != 0)
-      parse_line (env, s);
-  } while (s != 0) ;
+      {
+       if(!strlen(s))s = 0;
+       else parse_line (env, s);
+      }
+  } while ((s != 0) && !feof(fp)) ;
 
   fclose (fp);
   
@@ -214,11 +217,17 @@ PlugExport int plugin_run(struct arglist * desc)
    if      (!strcmp (tcp_scan, "connect()")) {
    	opt = "-sT";
 	raw_scan = 0;
-	}
-   else if (!strcmp (tcp_scan, "SYN scan"))  opt = "-sS";
-   else if (!strcmp (tcp_scan, "FIN scan"))  opt = "-sF";
-   else if (!strcmp (tcp_scan, "NULL Scan")) opt = "-sN";
-   else                                      opt = "-sX";
+	}	
+	
+   else if (!strcmp (tcp_scan, "SYN scan"))         opt = "-sS";
+   else if (!strcmp (tcp_scan, "FIN scan"))         opt = "-sF";
+   else if (!strcmp (tcp_scan, "NULL scan")) 	    opt = "-sN";
+   else if (!strcmp (tcp_scan, "Xmas Tree scan"))   opt = "-sX";
+   else    { 
+    	     /* default to connect() scan */
+   	     opt = "-sT";
+	     raw_scan = 0;
+	   }
    argv = append_argv (argv, opt);
  }
  
@@ -293,8 +302,9 @@ parse_line(env, line)
    			  Operating system guess                        
    							                
    --------------------------------------------------------------------*/
-  if(!strncmp(line, "Remote operating system guess",
-  			strlen( "Remote operating system guess")))
+  if(!strncmp(line, "Remote ",
+  			strlen( "Remote "))
+	&& (strstr(line, "OS guess") || strstr(line, "operating system")))
   {
    char * report = malloc(strlen(line)+1);
    t = strchr(line, ':');
@@ -304,7 +314,7 @@ parse_line(env, line)
    plug_set_key(env, "Host/OS", ARG_STRING, line);
    sprintf(report, "Nmap found that this host is running %s\n",
    			line);
-   proto_post_info(env, 0, "tcp", report);
+   proto_post_note(env, 0, "tcp", report);
    return;
   }
    
@@ -481,7 +491,7 @@ a potential security risk", s);
      /* t = <username> */
      
      sprintf(report, "This service is owned by user %s", t);
-     proto_post_info(env, num, protocol, report);
+     proto_post_note(env, num, protocol, report);
      free(report);
     }
   }
@@ -495,5 +505,5 @@ static int valid_port_range(char * r)
  if(!r[0])return 1;
  else
   if(!isdigit(r[0]) && (r[0]!='-') && (r[0]!=','))return 0;
-  else return valid_port_range(r+sizeof(char));
+  else return valid_port_range(++r);
  }
